@@ -101,7 +101,7 @@ check_rprofile_update_packages <- function(files = NULL, all = FALSE,
   if (length(files) == 0) return()
 
   patterns <- c(
-    "utils::update.packages()" = "update.packages[(][^)]*[)]",
+    "utils::update.packages()" = "update[.]packages[(][^)]*[)]",
     "pacman::p_up()" = "p_up[(][^)]*[)]"
   )
 
@@ -159,7 +159,7 @@ check_r_libs_env_vars <- function(debug = FALSE) {
     
     paths <- unlist(strsplit(path, split = .Platform$path.sep, fixed = TRUE))
     paths <- unique(paths)
-    paths <- paths[!is_dir(paths)]
+    paths <- paths[!vapply(paths, FUN = is_dir, FUN.VALUE = FALSE)]
     npaths <- length(paths)
     if (npaths > 0) {
       pathsx <- normalizePath(paths, mustWork = FALSE)
